@@ -11,7 +11,8 @@ import {
     TupleStorageFactoryServiceWeb,
     VortexService,
     VortexStatusService,
-    SqlFactoryService,
+    WebSqlBrowserFactoryService,
+    WebSqlFactoryService,
 } from "@synerty/vortexjs";
 import { AppRoutingModule } from "./app/app-routing.module";
 import { AppComponent } from "./app/app.component";
@@ -51,11 +52,14 @@ registerLocaleData(en);
             provide: ACE_CONFIG,
             useValue: DEFAULT_ACE_CONFIG,
         },
+        {
+            provide: WebSqlFactoryService,
+            useClass: WebSqlBrowserFactoryService,
+        },
         {
             provide: TupleStorageFactoryService,
             useClass: TupleStorageFactoryServiceWeb,
         },
-        SqlFactoryService,
         VortexService,
         VortexStatusService,
         BalloonMsgService,
